sqltriples.Query

Package sqltriples :: Module Query |
[show private | hide private]
[frames | no frames]

## Module sqltriples.Query

    Database querying classes.

    Copyright (C) 2006 Paul Boddie <paul@boddie.org.uk>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

Classes
`AbstractQuery` |
`CombinedResults` |
`CombinedTopLevelResults` |
`Conjunction` |
`ConjunctionOfObjects` |
`ConjunctionOfPredicates` |
`ConjunctionOfSubjects` |
`ConjunctionOfTriples` |
`ConjunctionOfTuples` |
`CountableResults` | A class representing a count of some results.
`Disjunction` |
`DisjunctionOfObjects` |
`DisjunctionOfPredicates` |
`DisjunctionOfSubjects` |
`DisjunctionOfTriples` |
`DisjunctionOfTuples` |
`Intersection` |
`IntersectionOfObjects` |
`IntersectionOfPredicates` |
`IntersectionOfSubjects` |
`IntersectionOfTriples` |
`IntersectionOfTuples` |
`Negation` | A class representing the negation of other results.
`NegationOfObjects` |
`NegationOfPredicates` |
`NegationOfSubjects` |
`NegationOfTriples` |
`NegationOfTuples` |
`Objects` | A class representing a selection of objects.
`Predicates` | A class representing a selection of predicates.
`Query` | An abstract class providing support for lazy query evaluation.
`Results` | A class representing a selection of results obtained by specifying a pattern.
`SingleResults` | A class representing a selection of single value results.
`Subject` | A class representing a more conveniently accessible subject.
`Subjects` | A class representing a selection of subjects.
`Triples` | A class representing a selection of triples.
`Tuples` | A class representing a selection of triples.

Exceptions
`NotSupportedError` |

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net